************************
aad_client
************************

Python Client for Packages Authenticating with Azure Active Directory

---------------------------

(Built from `package-template <https://github.com/djpugh/package-template>`_ version 1.0.0)